@@ -97,11 +97,9 @@ class CfnCluster(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -618,11 +616,9 @@ class CfnParameterGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -798,11 +794,9 @@ class CfnSubnetGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
